You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@dolphinscheduler.apache.org by zh...@apache.org on 2022/08/03 11:57:34 UTC

[dolphinscheduler] 14/16: Modify obsolete swagger parameters in AuditLogController (#10494)

This is an automated email from the ASF dual-hosted git repository.

zhongjiajie pushed a commit to branch 3.0.0-prepare
in repository https://gitbox.apache.org/repos/asf/dolphinscheduler.git

commit ae7df493a81dc4a619045e469beb74f6480e231b
Author: syyangs799 <55...@users.noreply.github.com>
AuthorDate: Sun Jun 19 22:54:14 2022 +0800

    Modify obsolete swagger parameters in AuditLogController (#10494)
    
    Co-authored-by: syyang <73...@user.noreply.gitee.com>
    (cherry picked from commit 79ce5d78cd22e5d548bd3285e169ba51b1a83d26)
---
 .../dolphinscheduler/api/controller/AuditLogController.java       | 8 +++-----
 1 file changed, 3 insertions(+), 5 deletions(-)

diff --git a/dolphinscheduler-api/src/main/java/org/apache/dolphinscheduler/api/controller/AuditLogController.java b/dolphinscheduler-api/src/main/java/org/apache/dolphinscheduler/api/controller/AuditLogController.java
index 1dfd298e15..fc04e2ada0 100644
--- a/dolphinscheduler-api/src/main/java/org/apache/dolphinscheduler/api/controller/AuditLogController.java
+++ b/dolphinscheduler-api/src/main/java/org/apache/dolphinscheduler/api/controller/AuditLogController.java
@@ -56,7 +56,7 @@ public class AuditLogController extends BaseController {
      *
      * @param loginUser         login user
      * @param pageNo            page number
      * @param moduleType        module type
      * @param operationType     operation type
      * @param startDate         start time
      * @param endDate           end time
@@ -68,11 +68,9 @@ public class AuditLogController extends BaseController {
     @ApiImplicitParams({
         @ApiImplicitParam(name = "startDate", value = "START_DATE", type = "String"),
         @ApiImplicitParam(name = "endDate", value = "END_DATE", type = "String"),
-        @ApiImplicitParam(name = "moduleType", value = "MODULE_TYPE", type = "String"),
-        @ApiImplicitParam(name = "operationType", value = "OPERATION_TYPE", type = "String"),
+        @ApiImplicitParam(name = "resourceType", value = "RESOURCE_TYPE", type = "AuditResourceType"),
+        @ApiImplicitParam(name = "operationType", value = "OPERATION_TYPE", type = "AuditOperationType"),
         @ApiImplicitParam(name = "userName", value = "USER_NAME", type = "String"),
-        @ApiImplicitParam(name = "projectName", value = "PROJECT_NAME", type = "String"),
-        @ApiImplicitParam(name = "processName", value = "PROCESS_NAME", type = "String"),
         @ApiImplicitParam(name = "pageNo", value = "PAGE_NO", required = true, dataType = "Int", example = "1"),
         @ApiImplicitParam(name = "pageSize", value = "PAGE_SIZE", required = true, dataType = "Int", example = "20")
     })
@@ -56,7 +56,7 @@ public class AuditLogController extends BaseController {
      * @param loginUser         login user
      * @param pageNo            page number
-     * @param moduleType        module type
+     * @param resourceType     resource type
      * @param operationType     operation type
      * @param startDate         start time